@@ -11,7 +11,7 @@ def get_legion_var():
     v = {}
     v['cli_path'] = os.path.dirname(os.path.abspath(__file__ + '/../../'))
     v['legion_path'] = os.path.abspath(v['cli_path'] + '/../')
-    v['server_path'] = os.path.abspath(v['legion_path'] + '/load-balancer/')
+    v['server_path'] = os.path.abspath(v['legion_path'] + '/legion/load-balancer/')
     v['tmp_server_path'] = '/tmp/legion-server'
 
     return v
